/**
 * Copyright (c) 2005-2012 EBM WebSourcing, 2012-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task;

import java.util.regex.Matcher;

import org.apache.tools.ant.BuildException;
import org.apache.tools.ant.types.LogLevel;
import org.ow2.petals.ant.AbstractJBIAntTask;

/**
 * Ant task : jbi-start-service-assembly. 
 * <p>
 * This task starts a particular service assembly in the JBI environment.
 * </p>
 * 
 * @author ddesjardins - EBM WebSourcing
 * @author Christophe Hamerling - EBM WebSourcing
 */
public class StartServiceAssemblyTask extends AbstractJBIAntTask {

    /**
     * Name of the JBI Service Assembly
     */
    private String name;

    /*
     * (non-Javadoc)
     * 
     * @see org.ow2.petals.ant.AbstractJBIAntTask#doTask()
     */
    @Override
    public void doTask() throws Exception {
        if (this.name == null) {
            throw new BuildException("Missing attribute 'name'");
        }

        final String serviceAssemblyReport = this.getJMXClient().getDeploymentServiceClient()
                .start(this.name);

        final Matcher matcher = saNamepattern.matcher(serviceAssemblyReport);
        if (matcher.find()) {
            if ("SUCCESS".equals(matcher.group(1).toUpperCase())) {
                log("Service Assembly '" + name + "' started");
            } else {
                log("Failed to start Service Assembly '" + name + "'", LogLevel.ERR.getLevel());
            }
        }
    }

    /**
     * Set the name parameter
     * 
     * @param name
     */
    public void setName(String name) {
        this.name = name;
    }
}
