/**
 * Copyright (c) 2015-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit;

import java.util.Collection;

import org.ow2.petals.ant.task.monit.exception.BuildRefIdInvalidException;

/**
 * Base class for Ant task working with MONIT traces and flow trees previously build by
 * {@link BuildFlowTreesTask}.
 * 
 * @author Christophe DENEUX - Linagora
 */
public abstract class AbstractMonitFlowTreesAntTaskRequiringRefId extends AbstractMonitAntTaskRequiringRefId {

    @Override
    public final void doTaskRequiringRefId(final Object referencedObject) throws Exception {

        if (referencedObject instanceof Collection) {
            this.doTaskWithFlowTrees((Collection<FlowTreeNode>) referencedObject);
        } else {
            throw new BuildRefIdInvalidException(this.getLocation());
        }
    }

    /**
     * Do the job of the task requiring 'refid' as a set of flow trees.
     *
     * @param flowTrees
     * @throws Exception
     */
    public abstract void doTaskWithFlowTrees(final Collection<FlowTreeNode> flowTrees) throws Exception;
}
