/**
 * Copyright (c) 2016-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit.assertion.flowtree;

import java.util.Collection;

import org.ow2.petals.ant.task.monit.AbstractMonitFlowTreesAntTaskRequiringRefId;
import org.ow2.petals.ant.task.monit.FlowTreeNode;
import org.ow2.petals.ant.task.monit.assertion.flowtree.exception.BuildAssertFlowTreesSizeException;
import org.ow2.petals.ant.task.monit.assertion.flowtree.exception.BuildAssertNoAssertionException;
import org.ow2.petals.ant.task.monit.assertion.flowtree.exception.BuildAssertTooManyAssertionsException;

/**
 * A Ant task to create asserts on flow trees read from MONIT traces.
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class AssertFlowTreesTask extends AbstractMonitFlowTreesAntTaskRequiringRefId {

    /**
     * The expected number of flow trees that must be equals
     */
    private Integer assertSizeEquals = null;

    /**
     * The expected number of flow trees that must be upper or equals
     */
    private Integer assertSizeUpperOrEquals = null;

    /**
     * @param assertSizeEquals
     */
    public void setAssertSizeEquals(final Integer assertSizeEquals) {
        this.assertSizeEquals = assertSizeEquals;
    }

    /**
     * @param assertSizeUpperOrEquals
     */
    public void setAssertSizeUpperOrEquals(final Integer assertSizeUpperOrEquals) {
        this.assertSizeUpperOrEquals = assertSizeUpperOrEquals;
    }

    @Override
    public final void doTaskWithFlowTrees(final Collection<FlowTreeNode> flowTrees) throws Exception {

        if (this.assertSizeEquals == null && this.assertSizeUpperOrEquals == null) {
            throw new BuildAssertNoAssertionException(this.getLocation());
        }

        if (this.assertSizeEquals != null && this.assertSizeUpperOrEquals != null) {
            throw new BuildAssertTooManyAssertionsException(this.getLocation());
        }

        if (this.assertSizeEquals != null && this.assertSizeEquals.intValue() != flowTrees.size()) {
            throw new BuildAssertFlowTreesSizeException(flowTrees.size(), this.assertSizeEquals.intValue(),
                    this.getLocation());
        }

        if (this.assertSizeUpperOrEquals != null && this.assertSizeUpperOrEquals.intValue() >= flowTrees.size()) {
            throw new BuildAssertFlowTreesSizeException(flowTrees.size(), this.assertSizeUpperOrEquals.intValue(),
                    this.getLocation());
        }
    }

}
