/**
 * Copyright (c) 2016-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit.assertion.flowtreenode;

import java.util.ArrayList;
import java.util.List;

/**
 * Assertions to execute on a flow tree node
 * 
 * @author Christophe DENEUX - Linagora
 */
public class AssertFlowTreeNode {

    /**
     * Assertions to execute on a flow tree node
     */
    private final List<FlowTreeNodeAssertion> assertions = new ArrayList<>();

    /**
     * <p>
     * Flow tree node path on which assertions must be executed.
     * </p>
     * <p>
     * Expression pattern: "x.y...z". Samples:
     * <ul>
     * <li>"": empty path identify the root flow tree node of the flow tree,</li>
     * <li>"0": select the 1St child of the root flow tree node,</li>
     * <li>"1": select the 2nd child of the root flow tree node,</li>
     * <li>"1.2": select the 3rd child of the 2nd child of the root flow tree node.</li>
     * </ul>
     * </p>
     */
    private String path;

    public void addFlowInstanceIdEquals(final FlowInstanceIdEquals flowInstanceIdEquals) {
        this.assertions.add(flowInstanceIdEquals);
    }

    /**
     * @param path
     *            A flow tree node path. Should be not {@code null}. Can be empty.
     */
    public void setPath(final String path) {
        this.path = path;
    }

    public String getPath() {
        return this.path;
    }

    public List<FlowTreeNodeAssertion> getAssertions() {
        return this.assertions;
    }

}
