/**
 * Copyright (c) 2015-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit;

import static org.junit.Assert.assertEquals;
import static org.junit.Assert.assertNotNull;
import static org.junit.Assert.assertTrue;

import java.io.File;
import java.net.URISyntaxException;
import java.net.URL;
import java.util.ArrayList;
import java.util.Collection;
import java.util.List;
import java.util.Set;

import org.apache.tools.ant.Project;
import org.apache.tools.ant.types.DirSet;

public abstract class AbstractMonitTraceTest {

    protected static final String REF_ID = "monit-traces";

    protected static final String REF_TREE_ID = "flow-trees";

    protected Project loadMonitTraces() throws URISyntaxException {
        final Project project = loadMonitTraces("monit/flow-monitoring");

        final Object monitTracesObj = project.getReference(REF_ID);
        assertEquals(7, ((Set<?>) monitTracesObj).size());
        return project;
    }

    protected Project loadMonitTraces(final String... resourceDirs) throws URISyntaxException {

        final Project project = new Project();
        final List<DirSet> dirSets = new ArrayList<>();
        for (final String resourceDir : resourceDirs) {
            final URL petalsRootLogFile = Thread.currentThread().getContextClassLoader().getResource(resourceDir);
            assertNotNull("Petals log file not found", petalsRootLogFile);

            final DirSet dirSet = new DirSet();
            dirSet.setDir(new File(petalsRootLogFile.toURI()));
            dirSet.setIncludes("**");
            dirSets.add(dirSet);
        }

        final ReadLogFilesTask rlfTask = new ReadLogFilesTask();
        rlfTask.setId(REF_ID);
        rlfTask.setProject(project);
        for (final DirSet dirSet : dirSets) {
            rlfTask.addDirSet(dirSet);
        }

        rlfTask.execute();

        final Object monitTracesObj = project.getReference(REF_ID);
        assertTrue(monitTracesObj instanceof Set);

        return project;
    }

    protected Project buildFlowTrees() throws URISyntaxException {
        final Project project = buildFlowTrees("monit/flow-monitoring-correlated/activiti",
                "monit/flow-monitoring-correlated/gw-container-0",
                "monit/flow-monitoring-correlated/gw-container-3.0",
                "monit/flow-monitoring-correlated/gw-container-3.1",
                "monit/flow-monitoring-correlated/gw-container-4.0",
                "monit/flow-monitoring-correlated/gw-container-4.1");

        final Object flowsObj = project.getReference(REF_ID);
        assertEquals(7, ((Set<?>) flowsObj).size()); // 4 for BC Gateway and 3 for Se Activiti
        final Object flowTreesObj = project.getReference(REF_TREE_ID);
        assertEquals(7, ((Collection<?>) flowTreesObj).size()); // 4 for BC Gateway and 3 for Se Activiti
        return project;
    }

    protected Project buildFlowTrees(final String... resourceDirs) throws URISyntaxException {

        final Project project = this.loadMonitTraces(resourceDirs);

        final BuildFlowTreesTask buildTreesTask = new BuildFlowTreesTask();
        buildTreesTask.setRefid(REF_ID);
        buildTreesTask.setId(REF_TREE_ID);
        buildTreesTask.setProject(project);
        buildTreesTask.execute();

        return project;
    }

}
