/**
 * Copyright (c) 2016-2017 Linagora
 * 
 * This program/library is free software: you can redistribute it and/or modify
 * it under the terms of the GNU Lesser General Public License as published by
 * the Free Software Foundation, either version 2.1 of the License, or (at your
 * option) any later version.
 * 
 * This program/library is distributed in the hope that it will be useful, but
 * WITHOUT ANY WARRANTY; without even the implied warranty of MERCHANTABILITY or
 * FITNESS FOR A PARTICULAR PURPOSE. See the GNU Lesser General Public License
 * for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public License
 * along with this program/library; If not, see http://www.gnu.org/licenses/
 * for the GNU Lesser General Public License version 2.1.
 */
package org.ow2.petals.ant.task.monit.assertion.flowtree;

import static org.junit.Assert.assertEquals;

import java.lang.reflect.InvocationTargetException;

import org.junit.Test;
import org.ow2.petals.ant.task.monit.FlowTreeNode;
import org.ow2.petals.ant.task.monit.assertion.flowtree.exception.BuildAssertFlowTreeNodeNotFoundException;

import com.ebmwebsourcing.easycommons.lang.reflect.ReflectionHelper;

/**
 * Unit tests of the private method {@code AssertFlowTreeTask.selectFlowTreeNode()}
 * 
 * @author Christophe DENEUX - Linagora
 *
 */
public class SelectFlowTreeNodeTest {

    private final static AssertFlowTreeTask task = new AssertFlowTreeTask();

    private final static FlowTreeNode rootTreeNode = new FlowTreeNode(null, null);

    private final static FlowTreeNode treeNode0 = new FlowTreeNode(null, rootTreeNode);

    private final static FlowTreeNode treeNode0_0 = new FlowTreeNode(null, treeNode0);

    private final static FlowTreeNode treeNode1 = new FlowTreeNode(null, rootTreeNode);

    private final static FlowTreeNode treeNode1_0 = new FlowTreeNode(null, treeNode1);

    private final static FlowTreeNode treeNode1_0_0 = new FlowTreeNode(null, treeNode1_0);

    private final static FlowTreeNode treeNode1_1 = new FlowTreeNode(null, treeNode1);

    @Test
    public void nominal() throws InvocationTargetException {
        
        assertEquals(rootTreeNode, ReflectionHelper.invokePrivateMethod(task, "selectFlowTreeNode",
                new Object[] { rootTreeNode, "" }, new Class[] { FlowTreeNode.class, String.class }));

        assertEquals(treeNode1_0_0, ReflectionHelper.invokePrivateMethod(task, "selectFlowTreeNode",
                new Object[] { rootTreeNode, "1.0.0" }, new Class[] { FlowTreeNode.class, String.class }));

        assertEquals(treeNode1_1, ReflectionHelper.invokePrivateMethod(task, "selectFlowTreeNode",
                new Object[] { rootTreeNode, "1.1" }, new Class[] { FlowTreeNode.class, String.class }));

        assertEquals(treeNode0_0, ReflectionHelper.invokePrivateMethod(task, "selectFlowTreeNode",
                new Object[] { rootTreeNode, "0.0" }, new Class[] { FlowTreeNode.class, String.class }));

    }

    @Test(expected = NumberFormatException.class)
    public void invalidExpr() throws Throwable {

        try {
            ReflectionHelper.invokePrivateMethod(task, "selectFlowTreeNode",
                    new Object[] { rootTreeNode, "invalid.expression.1" },
                    new Class[] { FlowTreeNode.class, String.class });
        } catch (final InvocationTargetException e) {
            throw e.getTargetException();
        }
    }

    @Test(expected = BuildAssertFlowTreeNodeNotFoundException.class)
    public void notFound() throws Throwable {

        try {
            ReflectionHelper.invokePrivateMethod(task, "selectFlowTreeNode", new Object[] { rootTreeNode, "0.10" },
                    new Class[] { FlowTreeNode.class, String.class });
        } catch (final InvocationTargetException e) {
            throw e.getTargetException();
        }
    }

}
